package com.ruoyi.ehsNoticeMessage.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.ehsNoticeMessage.domain.EhsNoticeMessage;
import com.ruoyi.ehsNoticeMessage.domain.EhsNoticeMessageDept;

/**
 * 内部公告Service接口
 *
 * @author ruoyi
 * @date 2023-12-06
 */
public interface IEhsNoticeMessageService extends IService<EhsNoticeMessage> {

	/**
	 * 查询内部公告
	 *
	 * @param noticeMessageId 内部公告主键
	 * @return 内部公告
	 */
	public EhsNoticeMessage selectEhsNoticeMessageByNoticeMessageId(Long noticeMessageId);

	/**
	 * 查询内部公告列表
	 *
	 * @param ehsNoticeMessage 内部公告
	 * @return 内部公告集合
	 */
	public List<EhsNoticeMessageDept> selectEhsNoticeMessageList(EhsNoticeMessageDept ehsNoticeMessage);


	public List<EhsNoticeMessage> selectEhsNoticeMessageListAdmin(EhsNoticeMessage ehsNoticeMessage);
	public int updateReadCompany(EhsNoticeMessage ehsNoticeMessage);
}
